@@ -67,7 +67,7 @@ class JupyterKernel:
         timeout : float, optional
             Default timeout in seconds.
         \*\*kwargs : dict
-            Arguments to pass to `start_kernel`. `cwd='some/path'` is one
+            Arguments to pass to `start_new_kernel`. `cwd='some/path'` is one
             example.
         """
         self.manager, self.client = start_new_kernel(
@@ -167,6 +167,8 @@ class JupyterKernel:
     def _process_output(self, msg):
         content = msg['content']
         msg_type = msg['msg_type']
+        if msg_type.startswith('comm_') or msg_type == 'clear_output':
+            return
         if msg_type == 'error':
             return dict(type='error',
                         message=msg,
@@ -190,6 +192,8 @@ class JupyterKernel:
             return dict(type='text',
                         message=msg,
                         content=data['text/plain'])
+        if 'text/html' in data:
+            return {}
         raise RuntimeError("Don't recognize data {}".format(data))
 
     def run_code(self, code, timeout=None,
